@@ -56,8 +56,12 @@ class ParameterMixin:
             If parameter is already in the model
         """
         if parameter_name in self.parameters:
-            warnings.warn(f"Key {parameter_name} is already in the model. Please use the update_parameters method")
-        self.add_and_update_parameter(parameter_name=parameter_name, parameter_value=parameter_value, **meta_info)
+            warnings.warn(
+                f"Key {parameter_name} is already in the model. Please use the update_parameters method"
+            )
+        self.add_and_update_parameter(
+            parameter_name=parameter_name, parameter_value=parameter_value, **meta_info
+        )
 
     def add_parameters(self, parameters, meta_info=None):
         """Add new parameters to the model.
@@ -105,7 +109,9 @@ class ParameterMixin:
         """
         if parameter_name not in self.parameters:
             warnings.warn(f"Key {parameter_name} is not in the model. Please use the add_parameters method")
-        self.add_and_update_parameter(parameter_name=parameter_name, parameter_value=parameter_value, **meta_info)
+        self.add_and_update_parameter(
+            parameter_name=parameter_name, parameter_value=parameter_value, **meta_info
+        )
 
     def update_parameters(self, parameters, meta_info=None):
         """Update existing model parameters.
@@ -173,7 +179,9 @@ class ParameterMixin:
                 info = meta_info[parameter_name]
             except KeyError:
                 info = {}
-            self.add_and_update_parameter(parameter_name=parameter_name, parameter_value=parameter_value, **info)
+            self.add_and_update_parameter(
+                parameter_name=parameter_name, parameter_value=parameter_value, **info
+            )
 
     def update_parameter_meta_info(self, parameter, meta_info):
         """Update meta info of a parameter.
@@ -228,6 +236,9 @@ class ParameterMixin:
         parameters : list(str)
             Names of parameters to be passed to the function
         """
+        # Do this first to check if all parameters are actually in the model
+        parameter_values = [self.parameters[i] for i in parameters]
+
         self.derived_parameters[parameter_name] = {
             "function": function,
             "parameters": parameters,
@@ -238,7 +249,7 @@ class ParameterMixin:
         # Initial calculation
         self.add_parameter(
             parameter_name=parameter_name,
-            parameter_value=function(*(self.parameters[i] for i in parameters)),
+            parameter_value=function(*parameter_values),
         )
 
     def remove_derived_parameter(self, parameter_name):
@@ -268,7 +279,9 @@ class ParameterMixin:
         for parameter_name, param_dict in self.derived_parameters.items():
             self.add_and_update_parameter(
                 parameter_name=parameter_name,
-                parameter_value=param_dict["function"](*(self.parameters[i] for i in param_dict["parameters"])),
+                parameter_value=param_dict["function"](
+                    *(self.parameters[i] for i in param_dict["parameters"])
+                ),
                 update_derived=False,
             )
 
@@ -346,7 +359,7 @@ class ParameterMixin:
     # Source code functions
     ##########################################################################
 
-    def _generate_parameters_source_code(self, include_meta_info=True):
+    def _generate_parameters_source_code(self, *, include_meta_info=True):
         """Generate modelbase source code for parameters.
 
         This is mainly used for the generate_model_source_code function.
@@ -372,7 +385,7 @@ class ParameterMixin:
     # SBML functions
     ##########################################################################
 
-    def _create_sbml_parameters(self, sbml_model):
+    def _create_sbml_parameters(self, *, sbml_model):
         """Create the parameters for the sbml model.
 
         Parameters
