@@ -53,7 +53,7 @@ class LabelModel(Model):
         )
 
     @staticmethod
-    def _generate_binary_labels(base_name, num_labels):
+    def _generate_binary_labels(*, base_name, num_labels):
         """Create binary label string.
 
         Parameters
@@ -100,7 +100,7 @@ class LabelModel(Model):
         if not is_isotopomer:
             self.nonlabel_compounds.append(compound)
 
-    def _add_base_compound(self, base_compound, num_labels, label_names, **meta_info):
+    def _add_base_compound(self, *, base_compound, num_labels, label_names, **meta_info):
         """Add a base compound of label isotopomer."""
         self.label_compounds[base_compound] = {
             "num_labels": num_labels,
@@ -108,7 +108,7 @@ class LabelModel(Model):
         }
         self.meta_info.setdefault("compounds", {}).setdefault(base_compound, Compound(**meta_info))
 
-    def _add_isotopomers(self, base_compound, label_names):
+    def _add_isotopomers(self, *, base_compound, label_names):
         # Add all labelled compounds
         for compound in label_names:
             self.add_compound(compound=compound, is_isotopomer=True)
@@ -290,7 +290,7 @@ class LabelModel(Model):
         )
 
     @staticmethod
-    def _split_label_string(label, labels_per_compound):
+    def _split_label_string(label, *, labels_per_compound):
         """Split label string according to labels given in label list.
 
         The labels in the label list correspond to the number of
@@ -329,7 +329,7 @@ class LabelModel(Model):
         return split_labels
 
     @staticmethod
-    def _map_substrates_to_products(rate_suffix, labelmap):
+    def _map_substrates_to_products(*, rate_suffix, labelmap):
         """Map the rate_suffix to products using the labelmap.
 
         Parameters
@@ -340,7 +340,7 @@ class LabelModel(Model):
         return "".join([rate_suffix[i] for i in labelmap])
 
     @staticmethod
-    def _unpack_stoichiometries(stoichiometries):
+    def _unpack_stoichiometries(*, stoichiometries):
         """Split stoichiometries into substrates and products.
 
         Parameters
@@ -361,7 +361,7 @@ class LabelModel(Model):
                 products.extend([k] * v)
         return substrates, products
 
-    def _get_labels_per_compound(self, compounds):
+    def _get_labels_per_compound(self, *, compounds):
         """Get labels per compound.
 
         This is used for _split_label string. Adds 0 for non-label compounds,
@@ -386,7 +386,7 @@ class LabelModel(Model):
         return labels_per_compound
 
     @staticmethod
-    def _repack_stoichiometries(new_substrates, new_products):
+    def _repack_stoichiometries(*, new_substrates, new_products):
         """Pack substrates and products into stoichiometric dict.
 
         Parameters
@@ -406,7 +406,7 @@ class LabelModel(Model):
         return dict(new_stoichiometries)
 
     @staticmethod
-    def _assign_compound_labels(base_compounds, label_suffixes):
+    def _assign_compound_labels(*, base_compounds, label_suffixes):
         """Assign the correct suffixes.
 
         Parameters
@@ -495,7 +495,7 @@ class LabelModel(Model):
             parameters=parameters,
         )
 
-    def _get_external_labels(self, rate_name, total_product_labels, total_substrate_labels, external_labels):
+    def _get_external_labels(self, *, rate_name, total_product_labels, total_substrate_labels, external_labels):
         n_external_labels = total_product_labels - total_substrate_labels
         if n_external_labels > 0:
             if not external_labels:
@@ -512,6 +512,7 @@ class LabelModel(Model):
 
     def _add_base_reaction(
         self,
+        *,
         rate_name,
         function,
         stoichiometry,
@@ -537,6 +538,7 @@ class LabelModel(Model):
 
     def _create_isotopomer_reactions(
         self,
+        *,
         rate_name,
         function,
         labelmap,
@@ -634,7 +636,7 @@ class LabelModel(Model):
         if modifiers is not None:
             modifiers = [i + "__total" if i in self.label_compounds else i for i in modifiers]
 
-        base_substrates, base_products = self._unpack_stoichiometries(stoichiometry)
+        base_substrates, base_products = self._unpack_stoichiometries(stoichiometries=stoichiometry)
         labels_per_substrate = self._get_labels_per_compound(compounds=base_substrates)
         labels_per_product = self._get_labels_per_compound(compounds=base_products)
         total_substrate_labels = sum(labels_per_substrate)
@@ -824,7 +826,7 @@ class LabelModel(Model):
         rates = [i for i in self.rates if i.startswith(rate_base_name + "__")]
         return self.get_fluxes_df(y=y, t=t)[rates].sum(axis=1).values
 
-    def _create_label_scope_seed(self, initial_labels):
+    def _create_label_scope_seed(self, *, initial_labels):
         """Create initial label scope seed.
 
         Parameters
@@ -921,7 +923,7 @@ class LabelModel(Model):
     # Model conversion functions
     ##########################################################################
 
-    def _map_label_compound_to_compound(self, compound):
+    def _map_label_compound_to_compound(self, *, compound):
         if compound in self.nonlabel_compounds:
             return compound
         else:
@@ -937,19 +939,19 @@ class LabelModel(Model):
         for module_name, module in self.algebraic_modules.items():
             if not module_name.endswith("__total"):
                 module = module.copy()
-                module["compounds"] = [self._map_label_compound_to_compound(i) for i in module["compounds"]]
+                module["compounds"] = [self._map_label_compound_to_compound(compound=i) for i in module["compounds"]]
                 module["derived_compounds"] = [
-                    self._map_label_compound_to_compound(i) for i in module["derived_compounds"]
+                    self._map_label_compound_to_compound(compound=i) for i in module["derived_compounds"]
                 ]
-                module["modifiers"] = [self._map_label_compound_to_compound(i) for i in module["modifiers"]]
+                module["modifiers"] = [self._map_label_compound_to_compound(compound=i) for i in module["modifiers"]]
                 m.add_algebraic_module(module_name=module_name, **module)
 
         for rate_name, reaction in self.base_reactions.items():
             reaction = reaction.copy()
             reaction["stoichiometry"] = {
-                self._map_label_compound_to_compound(k): v for k, v in reaction["stoichiometry"].items()
+                self._map_label_compound_to_compound(compound=k): v for k, v in reaction["stoichiometry"].items()
             }
-            reaction["modifiers"] = [self._map_label_compound_to_compound(i) for i in reaction["modifiers"]]
+            reaction["modifiers"] = [self._map_label_compound_to_compound(compound=i) for i in reaction["modifiers"]]
             del reaction["labelmap"]
             del reaction["external_labels"]
             del reaction["variants"]
@@ -960,7 +962,7 @@ class LabelModel(Model):
     # SBML functions
     ##########################################################################
 
-    def _add_sbml_compound(self, sbml_model, compound_id, common_name, compartment, charge, formula):
+    def _add_sbml_compound(self, *, sbml_model, compound_id, common_name, compartment, charge, formula):
         cpd = sbml_model.createSpecies()
         cpd.setId(convert_id_to_sbml(id_=compound_id, prefix="CPD"))
         if common_name is not None:
@@ -976,7 +978,7 @@ class LabelModel(Model):
         if formula is not None:
             cpd_fbc.setChemicalFormula(formula)
 
-    def _create_sbml_compounds(self, sbml_model):
+    def _create_sbml_compounds(self, *, sbml_model):
         """Create the compounds for the sbml model.
 
         Parameters
@@ -1015,7 +1017,7 @@ class LabelModel(Model):
                 formula=formula,
             )
 
-    def _create_sbml_reactions(self, sbml_model):
+    def _create_sbml_reactions(self, *, sbml_model):
         """Create the reactions for the sbml model.
 
         Parameters
