@@ -32,7 +32,7 @@ class LinearLabelModel(RateMixin, StoichiometricMixin, CompoundMixin, BaseModel)
         self.meta_info["model"].sbo = "SBO:0000062"  # continuous framework
 
     @staticmethod
-    def _generate_isotope_labels(base_name, num_labels):
+    def _generate_isotope_labels(*, base_name, num_labels):
         """Create binary label string.
 
         Parameters
@@ -120,7 +120,7 @@ class LinearLabelModel(RateMixin, StoichiometricMixin, CompoundMixin, BaseModel)
         self.meta_info.setdefault("rates", {}).setdefault(rate_name, Rate(**meta_info))
 
     @staticmethod
-    def _unpack_stoichiometries(stoichiometries):
+    def _unpack_stoichiometries(*, stoichiometries):
         """Split stoichiometries into substrates and products.
 
         Parameters
@@ -142,7 +142,7 @@ class LinearLabelModel(RateMixin, StoichiometricMixin, CompoundMixin, BaseModel)
         return substrates, products
 
     @staticmethod
-    def _add_label_influx_or_efflux(rate_name, substrates, products, labelmap):
+    def _add_label_influx_or_efflux(*, rate_name, substrates, products, labelmap):
         # Label outfluxes
         diff = len(substrates) - len(products)
         for _ in range(diff):
@@ -158,7 +158,7 @@ class LinearLabelModel(RateMixin, StoichiometricMixin, CompoundMixin, BaseModel)
                 substrates.append("EXT")
 
     @staticmethod
-    def _map_substrates_to_labelmap(substrates, labelmap):
+    def _map_substrates_to_labelmap(*, substrates, labelmap):
         return [substrates[i] for i in labelmap]
 
     def add_reaction(self, rate_name, stoichiometry, labelmap):
@@ -174,7 +174,7 @@ class LinearLabelModel(RateMixin, StoichiometricMixin, CompoundMixin, BaseModel)
             warnings.warn(f"Overwriting reaction {rate_name}")
             self.remove_reaction(rate_name=rate_name)
 
-        base_substrates, base_products = self._unpack_stoichiometries(stoichiometry)
+        base_substrates, base_products = self._unpack_stoichiometries(stoichiometries=stoichiometry)
         substrates = [j for i in base_substrates for j in self.isotopomers[i]]
         products = [j for i in base_products for j in self.isotopomers[i]]
 
@@ -232,7 +232,7 @@ class LinearLabelModel(RateMixin, StoichiometricMixin, CompoundMixin, BaseModel)
                     y0[f"{base_compound}__{pos}"] = 1 / len(label_positions)
         return y0
 
-    def _get_fluxes(self, y, v_ss, external_label=1):
+    def _get_fluxes(self, *, y, v_ss, external_label=1):
         y["EXT"] = external_label
 
         fluxes = {}
@@ -290,6 +290,8 @@ class LinearLabelModel(RateMixin, StoichiometricMixin, CompoundMixin, BaseModel)
             columns=self.get_rate_names(),
         )
 
+    # This can't get keyword-only arguments, as the integrators are calling it with
+    # positional arguments
     def _get_rhs(self, t, y_labels):
         y_labels = dict(zip(self.compounds, y_labels))
         dxdt = {i: 0 for i in y_labels}
@@ -330,7 +332,7 @@ class LinearLabelModel(RateMixin, StoichiometricMixin, CompoundMixin, BaseModel)
     # SBML functions
     ##########################################################################
 
-    def _create_sbml_reactions(self, sbml_model):
+    def _create_sbml_reactions(self, *, sbml_model):
         """Create the reactions for the sbml model.
 
         Parameters
