@@ -41,6 +41,7 @@ class Model(
         algebraic_modules=None,
         rate_stoichiometries=None,
         rates=None,
+        functions=None,
         meta_info=None,
     ):
         BaseModel.__init__(self, meta_info=meta_info)
@@ -48,7 +49,7 @@ class Model(
         ParameterMixin.__init__(self, parameters=parameters)
         AlgebraicMixin.__init__(self, algebraic_modules=algebraic_modules)
         StoichiometricMixin.__init__(self, rate_stoichiometries=rate_stoichiometries)
-        RateMixin.__init__(self, rates=rates)
+        RateMixin.__init__(self, rates=rates, functions=functions)
         self.meta_info["model"].sbo = "SBO:0000062"  # continuous framework
 
     def __str__(self):
