@@ -108,7 +108,7 @@ class _Simulate(_BaseSimulator):
         """
         self.model.update_parameters(parameters=parameters)
 
-    def _save_simulation_results(self, time, results, skipfirst):
+    def _save_simulation_results(self, *, time, results, skipfirst):
         super()._save_simulation_results(time=time, results=results, skipfirst=skipfirst)
         self.simulation_parameters.append(self.model.parameters.copy())
 
@@ -169,6 +169,7 @@ class _Simulate(_BaseSimulator):
     @staticmethod
     def _parameter_scan_worker(
         parameter_value,
+        *,
         parameter_name,
         model,
         Sim,
