@@ -11,7 +11,7 @@ from ..__init__ import Simulator
 _DISPLACEMENT = 1e-4
 
 
-def _find_steady_state(model, y0):
+def _find_steady_state(*, model, y0):
     """Simulate the system to steadt state.
 
     Just a convenience mapper.
@@ -225,7 +225,9 @@ def get_parameter_elasticities_df(model, parameters, y, t=0, normalized=True, di
     return pd.DataFrame(matrix, index=parameters, columns=model.get_rate_names())
 
 
-def get_concentration_response_coefficient(model, parameter, y, t=0, normalized=True, displacement=_DISPLACEMENT):
+def get_concentration_response_coefficient(
+    model, parameter, y, t=0, normalized=True, displacement=_DISPLACEMENT
+):
     """Get response of the steady state concentrations to a change of the given parameter.
 
     Parameters
@@ -292,7 +294,9 @@ def get_concentration_response_coefficients_array(
     return crs
 
 
-def get_concentration_response_coefficients_df(model, parameters, y, t=0, normalized=True, displacement=_DISPLACEMENT):
+def get_concentration_response_coefficients_df(
+    model, parameters, y, t=0, normalized=True, displacement=_DISPLACEMENT
+):
     """Get response of the steady state concentrations to a change of the given parameter m.
 
     Parameters
@@ -356,7 +360,9 @@ def get_flux_response_coefficient(model, parameter, y, t=0, normalized=True, dis
     return np.atleast_1d(np.squeeze(resp_coef))
 
 
-def get_flux_response_coefficients_array(model, parameters, y, t=0, normalized=True, displacement=_DISPLACEMENT):
+def get_flux_response_coefficients_array(
+    model, parameters, y, t=0, normalized=True, displacement=_DISPLACEMENT
+):
     """Get response of the steady state fluxes to a change of the given parameters.
 
     Parameters
@@ -421,6 +427,7 @@ def plot_concentration_response_coefficients(
     t=0,
     normalized=True,
     displacement=_DISPLACEMENT,
+    cmap="RdBu_r",
     ax=None,
     rows=None,
     columns=None,
@@ -455,7 +462,12 @@ def plot_concentration_response_coefficients(
         rows = df.index
     if columns is None:
         columns = df.columns
-    fig, ax, hm = _heatmap_from_dataframe(df.loc[rows, columns], title="Concentration Response Coefficients", ax=ax)
+    fig, ax, hm = _heatmap_from_dataframe(
+        df.loc[rows, columns],
+        title="Concentration Response Coefficients",
+        ax=ax,
+        cmap=cmap,
+    )
     ax.set_xticklabels(ax.get_xticklabels(), **{"rotation": 45, "ha": "right"})
     return fig, ax, hm
 
@@ -467,6 +479,7 @@ def plot_flux_response_coefficients(
     t=0,
     normalized=True,
     displacement=_DISPLACEMENT,
+    cmap="RdBu_r",
     ax=None,
     rows=None,
     columns=None,
@@ -501,6 +514,11 @@ def plot_flux_response_coefficients(
         rows = df.index
     if columns is None:
         columns = df.columns
-    fig, ax, hm = _heatmap_from_dataframe(df.loc[rows, columns], title="Flux Response Coefficients", ax=ax)
+    fig, ax, hm = _heatmap_from_dataframe(
+        df.loc[rows, columns],
+        title="Flux Response Coefficients",
+        ax=ax,
+        cmap=cmap,
+    )
     ax.set_xticklabels(ax.get_xticklabels(), **{"rotation": 45, "ha": "right"})
     return fig, ax, hm
