@@ -61,39 +61,39 @@ class ModelWarningsTests(unittest.TestCase):
 class ModelDerivedCompoundTests(unittest.TestCase):
     def test_add_derived_compound(self):
         model = Model()
-        model._add_derived_compound("x")
+        model._add_derived_compound(compound="x")
         self.assertEqual(model.compounds, [])
         self.assertEqual(model.derived_compounds, ["x"])
 
     def test_add_derived_compounds(self):
         model = Model()
-        model._add_derived_compounds(("x", "y"))
+        model._add_derived_compounds(compounds=("x", "y"))
         self.assertEqual(model.compounds, [])
         self.assertEqual(model.derived_compounds, ["x", "y"])
 
     def test_remove_derived_compound(self):
         model = Model()
-        model._add_derived_compounds(("x", "y"))
-        model._remove_derived_compound("x")
+        model._add_derived_compounds(compounds=("x", "y"))
+        model._remove_derived_compound(compound="x")
         self.assertEqual(model.compounds, [])
         self.assertEqual(model.derived_compounds, ["y"])
 
     def test_remove_derived_compounds(self):
         model = Model()
-        model._add_derived_compounds(("x", "y"))
-        model._remove_derived_compounds(("x", "y"))
+        model._add_derived_compounds(compounds=("x", "y"))
+        model._remove_derived_compounds(compounds=("x", "y"))
         self.assertEqual(model.compounds, [])
         self.assertEqual(model.derived_compounds, [])
 
     def test_get_derived_compounds(self):
         model = Model()
-        model._add_derived_compounds(("x", "y"))
+        model._add_derived_compounds(compounds=("x", "y"))
         self.assertEqual(model.get_derived_compounds(), ["x", "y"])
 
     def test_get_all_compounds(self):
         model = Model()
         model.add_compound("A")
-        model._add_derived_compounds(("x", "y"))
+        model._add_derived_compounds(compounds=("x", "y"))
         self.assertEqual(model.get_all_compounds(), ["A", "x", "y"])
 
     ############################################################################
@@ -637,6 +637,6 @@ class SBMLTests(unittest.TestCase):
             parameters=["keq"],
         )
         doc = model._create_sbml_document()
-        sbml_model = model._create_sbml_model(doc)
+        sbml_model = model._create_sbml_model(doc=doc)
         with self.assertWarns(UserWarning):
-            model._create_sbml_algebraic_modules(sbml_model)
+            model._create_sbml_algebraic_modules(sbml_model=sbml_model)
