@@ -2,6 +2,7 @@
 import unittest
 
 # Third party
+import pytest
 from modelbase.ode import Model
 from modelbase.ode import ratefunctions as rf
 
@@ -623,3 +624,49 @@ class SBMLTests(unittest.TestCase):
         self.assertEqual(rxn.getListOfModifiers()[0].getSpecies(), "ATP")
         self.assertEqual(rxn.getListOfModifiers()[1].getSpecies(), "ADP")
         self.assertEqual(rxn.getKineticLaw().getFormula(), "x * ATP - y * ADP")
+
+
+# New tests using pytest
+def test_init_functions():
+    def func1():
+        return 1
+
+    def func2():
+        return 2
+
+    functions = {
+        "func1": func1,
+        "func2": func2,
+    }
+    model = Model(functions=functions)
+    assert set(model.functions.keys()) == {"func1", "func2"}
+
+
+def test_add_function():
+    def func(x):
+        return x
+
+    model = Model()
+    model.add_function("func", func)
+    assert model.functions["func"] == func
+
+
+def test_add_function_lambda():
+    model = Model()
+    model.add_function("func", lambda x: x)
+    assert model.functions["func"].__name__ == "func"
+
+
+def test_generate_function_source_code():
+    def func(x):
+        return x
+
+    model = Model()
+    model.add_function("func", func)
+    model.add_function("func2", lambda x: x)
+    assert model._generate_function_source_code().split("\n") == [
+        "def func(x):",
+        "    return x",
+        "def func2(x):",
+        "    return",
+    ]
