@@ -531,19 +531,19 @@ class LabelModelTests(unittest.TestCase):
 
     def test_unpack_stoichiometries(self):
         self.assertEqual(
-            LabelModel._unpack_stoichiometries({"x": -1, "y": 1}),
+            LabelModel._unpack_stoichiometries(stoichiometries={"x": -1, "y": 1}),
             (["x"], ["y"]),
         )
         self.assertEqual(
-            LabelModel._unpack_stoichiometries({"x": -2, "y": 1}),
+            LabelModel._unpack_stoichiometries(stoichiometries={"x": -2, "y": 1}),
             (["x", "x"], ["y"]),
         )
         self.assertEqual(
-            LabelModel._unpack_stoichiometries({"x": -1, "y": 2}),
+            LabelModel._unpack_stoichiometries(stoichiometries={"x": -1, "y": 2}),
             (["x"], ["y", "y"]),
         )
         self.assertEqual(
-            LabelModel._unpack_stoichiometries({"y": 1, "x": -1}),
+            LabelModel._unpack_stoichiometries(stoichiometries={"y": 1, "x": -1}),
             (["x"], ["y"]),
         )
 
@@ -591,17 +591,17 @@ class LabelModelTests(unittest.TestCase):
         )
 
     def test_assign_compound_labels_no_label(self):
-        self.assertEqual(LabelModel._assign_compound_labels(["x"], [""]), ["x"])
+        self.assertEqual(LabelModel._assign_compound_labels(base_compounds=["x"], label_suffixes=[""]), ["x"])
 
     def test_assign_compound_labels_one_label(self):
         self.assertEqual(
-            LabelModel._assign_compound_labels(["x"], ["0"]),
+            LabelModel._assign_compound_labels(base_compounds=["x"], label_suffixes=["0"]),
             ["x__0"],
         )
 
     def test_assign_compound_labels(self):
         self.assertEqual(
-            LabelModel._assign_compound_labels(["x", "y"], ["0", "1"]),
+            LabelModel._assign_compound_labels(base_compounds=["x", "y"], label_suffixes=["0", "1"]),
             ["x__0", "y__1"],
         )
 
@@ -1325,8 +1325,8 @@ class SBMLTests(unittest.TestCase):
         m.add_label_compounds({"X": 2, "Y": 2})
 
         doc = m._create_sbml_document()
-        sbml_model = m._create_sbml_model(doc)
-        m._create_sbml_compounds(sbml_model)
+        sbml_model = m._create_sbml_model(doc=doc)
+        m._create_sbml_compounds(sbml_model=sbml_model)
 
         self.assertEqual(
             [i.getId() for i in sbml_model.getListOfSpecies()],
@@ -1373,8 +1373,8 @@ class SBMLTests(unittest.TestCase):
         )
 
         doc = m._create_sbml_document()
-        sbml_model = m._create_sbml_model(doc)
-        m._create_sbml_compounds(sbml_model)
+        sbml_model = m._create_sbml_model(doc=doc)
+        m._create_sbml_compounds(sbml_model=sbml_model)
 
         self.assertEqual(
             [i.getId() for i in sbml_model.getListOfSpecies()],
@@ -1425,8 +1425,8 @@ class SBMLTests(unittest.TestCase):
         )
 
         doc = m._create_sbml_document()
-        sbml_model = m._create_sbml_model(doc)
-        m._create_sbml_reactions(sbml_model)
+        sbml_model = m._create_sbml_model(doc=doc)
+        m._create_sbml_reactions(sbml_model=sbml_model)
 
         self.assertEqual(
             [i.getId() for i in sbml_model.getListOfReactions()],
@@ -1481,8 +1481,8 @@ class SBMLTests(unittest.TestCase):
         )
 
         doc = m._create_sbml_document()
-        sbml_model = m._create_sbml_model(doc)
-        m._create_sbml_reactions(sbml_model)
+        sbml_model = m._create_sbml_model(doc=doc)
+        m._create_sbml_reactions(sbml_model=sbml_model)
 
         rxn = sbml_model.getReaction("v1__00")
         self.assertEqual(rxn.getName(), "test")
