@@ -1205,7 +1205,10 @@ class SourceCodeTests(unittest.TestCase):
         self.assertEqual(
             model.generate_model_source_code(linted=False, include_meta_info=False).strip().split("\n"),
             [
+                "import math",
+                "import numpy as np",
                 "from modelbase.ode import Model, Simulator",
+                "",
                 "def module(x, y):",
                 "    return [x / y]  # pragma: no cover",
                 "def rate(s, z, k_fwd):",
@@ -1254,7 +1257,10 @@ class SourceCodeTests(unittest.TestCase):
         self.assertEqual(
             model.generate_model_source_code(linted=False, include_meta_info=True).strip().split("\n"),
             [
+                "import math",
+                "import numpy as np",
                 "from modelbase.ode import Model, Simulator",
+                "",
                 "def module(x, y):",
                 "    return [x / y]  # pragma: no cover",
                 "def rate(s, z, k_fwd):",
@@ -1304,6 +1310,8 @@ class SourceCodeTests(unittest.TestCase):
         self.assertEqual(
             model.generate_model_source_code(linted=True, include_meta_info=False).strip().split("\n"),
             [
+                "import math",
+                "import numpy as np",
                 "from modelbase.ode import Model, Simulator",
                 "",
                 "",
@@ -1358,6 +1366,8 @@ class SourceCodeTests(unittest.TestCase):
         self.assertEqual(
             model.generate_model_source_code(linted=True, include_meta_info=True).strip().split("\n"),
             [
+                "import math",
+                "import numpy as np",
                 "from modelbase.ode import Model, Simulator",
                 "",
                 "",
@@ -1433,8 +1443,8 @@ class SBMLTests(unittest.TestCase):
         )
 
         doc = model._create_sbml_document()
-        sbml_model = model._create_sbml_model(doc)
-        model._create_sbml_reactions(sbml_model)
+        sbml_model = model._create_sbml_model(doc=doc)
+        model._create_sbml_reactions(sbml_model=sbml_model)
 
         rxn = sbml_model.getReaction("v1")
         self.assertEqual(rxn.getId(), "v1")
@@ -1462,8 +1472,8 @@ class SBMLTests(unittest.TestCase):
         )
 
         doc = model._create_sbml_document()
-        sbml_model = model._create_sbml_model(doc)
-        model._create_sbml_reactions(sbml_model)
+        sbml_model = model._create_sbml_model(doc=doc)
+        model._create_sbml_reactions(sbml_model=sbml_model)
 
         rxn = sbml_model.getReaction("v1")
         self.assertEqual(rxn.getId(), "v1")
