@@ -4,6 +4,7 @@ from tempfile import TemporaryDirectory
 
 # Third party
 import numpy as np
+import pytest
 from modelbase.ode import Model, Simulator
 from modelbase.ode import ratefunctions as rf
 
@@ -394,3 +395,12 @@ class SimulationTests(unittest.TestCase):
             [0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0],
         )
         self.assertEqual(res.columns.values.tolist(), ["a", "b", "c1", "c2", "d1", "d2", "rate_time"])
+
+
+# new tests using pytest
+def test_simulate_warn_no_rates_set():
+    model = Model()
+    sim = Simulator(model)
+    sim.initialise(y0={})
+    with pytest.warns(UserWarning):
+        sim.simulate(t_end=1)
